[Schmitzm-commits] r485 - in branches/1.0-gt2-2.6/src: gtmig/org/geotools/swing schmitzm/geotools/gui schmitzm/jfree
scm-commit@wald.intevation.org
scm-commit at wald.intevation.org
Tue Oct 20 18:22:52 CEST 2009
Author: mojays
Date: 2009-10-20 18:22:47 +0200 (Tue, 20 Oct 2009)
New Revision: 485
Modified:
branches/1.0-gt2-2.6/src/gtmig/org/geotools/swing/JMapPane.java
branches/1.0-gt2-2.6/src/schmitzm/geotools/gui/FeatureCollectionFilterPanel.java
branches/1.0-gt2-2.6/src/schmitzm/geotools/gui/FeatureTablePane.java
branches/1.0-gt2-2.6/src/schmitzm/geotools/gui/JMapPane.java
branches/1.0-gt2-2.6/src/schmitzm/jfree/JFreeChartUtil.java
Log:
Modified: branches/1.0-gt2-2.6/src/gtmig/org/geotools/swing/JMapPane.java
===================================================================
--- branches/1.0-gt2-2.6/src/gtmig/org/geotools/swing/JMapPane.java 2009-10-20 15:32:58 UTC (rev 484)
+++ branches/1.0-gt2-2.6/src/gtmig/org/geotools/swing/JMapPane.java 2009-10-20 16:22:47 UTC (rev 485)
@@ -1133,7 +1133,7 @@
);
} catch (IOException e) {
LOGGER.warn(
- "maxExtend == null; faild to getLayerBounds of context",
+ "maxExtend == null; failed to getLayerBounds of context",
e);
}
}
Modified: branches/1.0-gt2-2.6/src/schmitzm/geotools/gui/FeatureCollectionFilterPanel.java
===================================================================
--- branches/1.0-gt2-2.6/src/schmitzm/geotools/gui/FeatureCollectionFilterPanel.java 2009-10-20 15:32:58 UTC (rev 484)
+++ branches/1.0-gt2-2.6/src/schmitzm/geotools/gui/FeatureCollectionFilterPanel.java 2009-10-20 16:22:47 UTC (rev 485)
@@ -281,14 +281,12 @@
protected void initGUI(boolean geomPreview) {
super.initGUI(geomPreview);
- mapPane
- .setToolTipText(GeotoolsGUIUtil
- .R(FeatureCollectionFilterPanel.PREVIEW_MAPPANE_TOOLTIP));
+ mapPane.setToolTipText(
+ GeotoolsGUIUtil.R(FeatureCollectionFilterPanel.PREVIEW_MAPPANE_TOOLTIP));
// nur einzelne Zellen duerfen selektiert werden
featuresTable.setColumnSelectionAllowed(true);
- featuresTable
- .setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
+ featuresTable.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
// beim Klick auf eine Tabellenzelle, soll der Wert in die
// Formel
// uebernommen werden
@@ -296,9 +294,6 @@
public void mouseClicked(MouseEvent e) {
if (e.getButton() == MouseEvent.BUTTON1
&& e.getClickCount() == 2)
-
- // * TODO SK: Might have to be changed to Sorted
- // / RowModel stuff ....?!
insertValueInRule(featuresTable.getValueAt(
featuresTable.getSelectedRow(),
featuresTable.getSelectedColumn()));
@@ -510,7 +505,8 @@
// Nur numerische Werte direkt in Formel einfuegen.
// Andere Werte als String in Anfuehrungsstrichen gekapselt.
if (!(value instanceof Number))
- ruleValue = "\"" + ruleValue + "\"";
+// ruleValue = "\"" + ruleValue + "\"";
+ ruleValue = "'" + ruleValue + "'"; // more common (e.g. for CQL)
// Wert in Formel einfuegen
performOperatorInsert(ruleValue, (JTextField) this.rule
.getInputComponent());
Modified: branches/1.0-gt2-2.6/src/schmitzm/geotools/gui/FeatureTablePane.java
===================================================================
--- branches/1.0-gt2-2.6/src/schmitzm/geotools/gui/JMapPane.java 2009-10-20 15:32:58 UTC (rev 484)
+++ branches/1.0-gt2-2.6/src/schmitzm/geotools/gui/JMapPane.java 2009-10-20 16:22:47 UTC (rev 485)
@@ -523,9 +523,10 @@
// verwenden, so dass die erste
// Karte komplett angezeigt wird
if (getMapArea() == null) {
- Envelope newMapArea = new Envelope(e.getLayer()
- .getFeatureSource().getBounds());
- setMapArea(getMaxExtend());
+// Envelope newMapArea = new Envelope(e.getLayer()
+// .getFeatureSource().getBounds());
+ Envelope newMapArea = getMaxExtend();
+ setMapArea(newMapArea);
// in layerAdded(.) der Oberklasse wird
// mapArea nochmal neu gesetzt, wenn das
// erste Layer
Modified: branches/1.0-gt2-2.6/src/schmitzm/jfree/JFreeChartUtil.java
===================================================================
--- branches/1.0-gt2-2.6/src/schmitzm/jfree/JFreeChartUtil.java 2009-10-20 15:32:58 UTC (rev 484)
+++ branches/1.0-gt2-2.6/src/schmitzm/jfree/JFreeChartUtil.java 2009-10-20 16:22:47 UTC (rev 485)
@@ -181,7 +181,8 @@
* {@value #DEFAULT_CENTRATION_BOUNDARY_PCT} is used).
*/
public static void centerAxis(ValueAxis axis, Double boundaryPct) {
- // first recalculate the full extend
+ // first recalculate the full extend (unfortunately the listeners are
+ // called; the method to de-activate this behavior is protected!)
axis.setAutoRange(true);
// then reset the centering
double absMax = getAbsRange(axis.getRange(),boundaryPct);
More information about the Schmitzm-commits
mailing list
--- branches/1.0-gt2-2.6/src/schmitzm/geotools/gui/FeatureTablePane.java 2009-10-20 15:32:58 UTC (rev 484)
+++ branches/1.0-gt2-2.6/src/schmitzm/geotools/gui/FeatureTablePane.java 2009-10-20 16:22:47 UTC (rev 485)
@@ -55,6 +55,7 @@
import org.opengis.feature.simple.SimpleFeatureType;
import schmitzm.geotools.feature.AttributeTypeFilter;
+import schmitzm.geotools.feature.FeatureTableModel;
import schmitzm.geotools.feature.FeatureUtil;
import schmitzm.geotools.styling.StylingUtil;
import schmitzm.swing.JPanel;
@@ -68,7 +69,7 @@
* <br>
* <b>Bemerkung:</b><br>
* Als {@code TableModel} fuer die SimpleFeature-Tabelle verwendet diese Klasse ein
* eigenes internes {@link TableModel}, welches effizienter arbeitet, als
* {@link org.geotools.swing.table.FeatureTableModel
* org.geotools.swing.table.FeatureTableModel}.
*
@@ -68,7 +69,7 @@
* <b>Bemerkung:</b><br>
* Als {@code TableModel} fuer die SimpleFeature-Tabelle verwendet diese Klasse ein
- * eigenes internes {@link TableModel}, welches effizienter arbeitet, als
+ * eigenes internes {@link FeatureCollectionTableModel}, welches effizienter arbeitet, als
* {@link org.geotools.swing.table.FeatureTableModel
* org.geotools.swing.table.FeatureTableModel}.
Modified: branches/1.0-gt2-2.6/src/schmitzm/geotools/gui/JMapPane.java
===================================================================